@@ -4,6 +4,9 @@ use Moose;
 
 with 'Business::OnlinePayment::Iridium::Action';
 
+# PODNAME: Business::OnlinePayment::Iridium::Action::CardDetailsTransaction
+# ABSTRACT: Handle PayVector card details
+
 has 'OrderID' => (
     isa      => 'Str',
     is       => 'rw',
@@ -178,6 +181,7 @@ has 'PassOutData' => (
 
 sub _build__type { return 'CardDetailsTransaction' }
 
+
 sub template {
     return <<DATA;
 <?xml version="1.0" encoding="utf-8"?>
@@ -234,3 +238,34 @@ DATA
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Business::OnlinePayment::Iridium::Action::CardDetailsTransaction - Handle PayVector card details
+
+=head1 VERSION
+
+version 1.00
+
+=head2 template
+
+SOAP template to use to send to PayVector / Iridium
+
+=head1 AUTHOR
+
+[ 'Gavin Henry <ghenry@surevoip.co.uk>', 'Wallace Reis <reis.wallace@gmail.com>' ]
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by [ 'Gavin Henry', 'Wallace Reis' ].
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
